==> comfyui_embedded_docs-0.2.0-py3-none-any.whl: comfyui_embedded_docs/docs/InpaintModelConditioning/fr.md <==

Le nœud InpaintModelConditioning est conçu pour faciliter le processus de conditionnement pour les modèles d'inpainting, permettant l'intégration et la manipulation de divers entrées de conditionnement pour adapter le résultat de l'inpainting. Il englobe une large gamme de fonctionnalités, allant du chargement de points de contrôle de modèles spécifiques et de l'application de modèles de style ou de réseau de contrôle, à l'encodage et à la combinaison d'éléments de conditionnement, servant ainsi d'outil complet pour personnaliser les tâches d'inpainting.

## Types d'entrée
| Paramètre | Comfy dtype        | Description |
|-----------|--------------------|-------------|
| `positive`| `CONDITIONING`     | Représente les informations ou paramètres de conditionnement positifs à appliquer au modèle d'inpainting. Cette entrée est cruciale pour définir le contexte ou les contraintes dans lesquelles l'opération d'inpainting doit être effectuée, affectant significativement le résultat final. |
| `negative`| `CONDITIONING`     | Représente les informations ou paramètres de conditionnement négatifs à appliquer au modèle d'inpainting. Cette entrée est essentielle pour spécifier les conditions ou contextes à éviter pendant le processus d'inpainting, influençant ainsi le résultat final. |
| `vae`     | `VAE`              | Spécifie le modèle VAE à utiliser dans le processus de conditionnement. Cette entrée est cruciale pour déterminer l'architecture spécifique et les paramètres du modèle VAE qui seront utilisés. |
| `pixels`  | `IMAGE`            | Représente les données de pixels de l'image à inpeindre. Cette entrée est essentielle pour fournir le contexte visuel nécessaire à la tâche d'inpainting. |
| `mask`    | `MASK`             | Spécifie le masque à appliquer à l'image, indiquant les zones à inpeindre. Cette entrée est cruciale pour définir les régions spécifiques de l'image nécessitant un inpainting. |

## Types de sortie

| Paramètre | Comfy dtype  | Description |
|-----------|--------------|-------------|
| `positive`| `CONDITIONING` | Les informations de conditionnement positif modifiées après traitement, prêtes à être appliquées au modèle d'inpainting. Cette sortie est essentielle pour guider le processus d'inpainting selon les conditions positives spécifiées. |
| `negative`| `CONDITIONING` | Les informations de conditionnement négatif modifiées après traitement, prêtes à être appliquées au modèle d'inpainting. Cette sortie est essentielle pour guider le processus d'inpainting selon les conditions négatives spécifiées. |
| `latent`  | `LATENT`     | La représentation latente dérivée du processus de conditionnement. Cette sortie est cruciale pour comprendre les caractéristiques sous-jacentes de l'image en cours d'inpainting. |

==> comfyui_embedded_docs-0.2.3-py3-none-any.whl: comfyui_embedded_docs/docs/InpaintModelConditioning/fr.md <==

Le nœud InpaintModelConditioning est conçu pour faciliter le processus de conditionnement pour les modèles d'inpainting, permettant l'intégration et la manipulation de divers entrées de conditionnement pour adapter le résultat de l'inpainting. Il englobe une large gamme de fonctionnalités, allant du chargement de points de contrôle de modèles spécifiques et de l'application de modèles de style ou de réseau de contrôle, à l'encodage et à la combinaison d'éléments de conditionnement, servant ainsi d'outil complet pour personnaliser les tâches d'inpainting.

## Entrées

| Paramètre | Comfy dtype        | Description |
|-----------|--------------------|-------------|
| `positive`| `CONDITIONING`     | Représente les informations ou paramètres de conditionnement positifs à appliquer au modèle d'inpainting. Cette entrée est cruciale pour définir le contexte ou les contraintes dans lesquelles l'opération d'inpainting doit être effectuée, affectant significativement le résultat final. |
| `negative`| `CONDITIONING`     | Représente les informations ou paramètres de conditionnement négatifs à appliquer au modèle d'inpainting. Cette entrée est essentielle pour spécifier les conditions ou contextes à éviter pendant le processus d'inpainting, influençant ainsi le résultat final. |
| `vae`     | `VAE`              | Spécifie le modèle VAE à utiliser dans le processus de conditionnement. Cette entrée est cruciale pour déterminer l'architecture spécifique et les paramètres du modèle VAE qui seront utilisés. |
| `pixels`  | `IMAGE`            | Représente les données de pixels de l'image à inpeindre. Cette entrée est essentielle pour fournir le contexte visuel nécessaire à la tâche d'inpainting. |
| `mask`    | `MASK`             | Spécifie le masque à appliquer à l'image, indiquant les zones à inpeindre. Cette entrée est cruciale pour définir les régions spécifiques de l'image nécessitant un inpainting. |

## Sorties

| Paramètre | Type de Donnée | Description |
|-----------|--------------|-------------|
| `positive`| `CONDITIONING` | Les informations de conditionnement positif modifiées après traitement, prêtes à être appliquées au modèle d'inpainting. Cette sortie est essentielle pour guider le processus d'inpainting selon les conditions positives spécifiées. |
| `negative`| `CONDITIONING` | Les informations de conditionnement négatif modifiées après traitement, prêtes à être appliquées au modèle d'inpainting. Cette sortie est essentielle pour guider le processus d'inpainting selon les conditions négatives spécifiées. |
| `latent`  | `LATENT`     | La représentation latente dérivée du processus de conditionnement. Cette sortie est cruciale pour comprendre les caractéristiques sous-jacentes de l'image en cours d'inpainting. |
